package com.huatek.busi.common;

import java.util.Arrays;
import java.util.Optional;

import lombok.Getter;

/**
 * 业务常量定义
 *
 * @author anker cheng
 *
 * @Date 2019年6月26日
 */
public final class BusiConstant {

    /**
     * 告警弹框分页大小
     */
    public static final int MAX_WARNING_PAGE_SIZE = 100;

    /**
     * 测温类虚拟节点
     */
    public static final ValueNamePair TMP_POINT_EQM = new ValueNamePair("000", "测温点");

    private BusiConstant() {}

    /**
     * 故障大类 ；1：变压器，2：gis，3：避雷器，4：测温柜，5：其他, 6: 发电机 7：电缆
     *
     * @author anker_cheng
     * @date 2019/07/12
     */
    public static interface EqType {
        String EQ_TYPE1 = "1";
        String EQ_TYPE2 = "2";
        // 避雷器告警大类
        String EQ_TYPE3 = "3";
        // 开关柜告警大类
        String EQ_TYPE4 = "4";
        String EQ_TYPE5 = "5";
        String EQ_TYPE6 = "6";
        String EQ_TYPE7 = "7";
        // 附件告警大类
        String EQ_TYPE8 = "8";
    }

    /** 报警——故障小类 */
    public static interface GzType {
        /** 故障小类：1——油色谱 */
        String GZ_TYPE1 = "1";
        /** 故障小类：2——局放 */
        String GZ_TYPE2 = "2";
        /** 故障小类：3——铁芯接地 */
        String GZ_TYPE3 = "3";
        /** 故障小类：4——红外测温 */
        String GZ_TYPE4 = "4";
        /** 故障小类：5——SF6告警 */
        String GZ_TYPE5 = "5";
        /** 故障小类：6——避雷器告警 */
        String GZ_TYPE6 = "6";
        /** 故障小类：7——测温柜测温告警 */
        String GZ_TYPE7 = "7";
        /** 故障小类：8——铁芯夹件告警 */
        String GZ_TYPE8 = "8";
        /** 故障小类：9——变压器运行工况 */
        String GZ_TYPE9 = "9";
        /** 故障小类：10——测温点增长率 */
        String GZ_TYPE10 = "10";
        /** 故障小类：11——读表数据 */
        String GZ_TYPE11 = "11";
        /** 故障小类：12——容性 */
        String GZ_TYPE12 = "12";
        /** 故障小类：13——套管 */
        String GZ_TYPE13 = "13";
        /** 故障小类：15——声级震动 */
        String GZ_TYPE15 = "15";
        /** 故障小类：16——电缆局放 */
        String GZ_TYPE16 = "16";
        /** 故障小类：17——电缆环流(阈值告警) */
        String GZ_TYPE17 = "17";
        /** 故障小类：18——电缆环流(增长率告警) */
        String GZ_TYPE18 = "18";
        /** 故障小类：19——电缆沟 */
        String GZ_TYPE19 = "19";
        /** 故障小类：20——绕组测温 */
        String GZ_TYPE20 = "20";
        /** 故障小类：21——测温装置 */
        String GZ_TYPE21 = "21";
        /** 故障小类：22——SF6环境监测 */
        String GZ_TYPE22 = "22";
        /** 故障小类：23——发电机振动 */
        String GZ_TYPE23 = "23";
        /** 故障小类：24——发电机压力 */
        String GZ_TYPE24 = "24";

        /** 故障小类：25——评测异常 */
        String GZ_TYPE25 = "25";

        /** 故障小类：27——气象 */
        String GZ_TYPE27 = "27";

        String GZ_TYPE26 = "26";
    }

    /**
     * 根据故障类型返回故障中文描述
     * @param type
     * @return
     */
    public static String getGzTypeDescribe(String type) {
        String typeDesc="";
        if(GzType.GZ_TYPE1.equals(type))
        {
            typeDesc="油色谱";
        }else if(GzType.GZ_TYPE2.equals(type))
        {
            typeDesc="局放";
        }else if(GzType.GZ_TYPE3.equals(type))
        {
            typeDesc="铁芯接地";
        }else if(GzType.GZ_TYPE4.equals(type))
        {
            typeDesc="红外测温";
        }else if(GzType.GZ_TYPE5.equals(type))
        {
            typeDesc="SF6告警";
        }else if(GzType.GZ_TYPE6.equals(type))
        {
            typeDesc="避雷器告警";
        }else if(GzType.GZ_TYPE7.equals(type))
        {
            typeDesc="测温柜测温告警";
        }else if(GzType.GZ_TYPE8.equals(type))
        {
            typeDesc="夹件电流";
        }else if(GzType.GZ_TYPE9.equals(type))
        {
            typeDesc="运行工况告警";
        }else if(GzType.GZ_TYPE10.equals(type))
        {
            typeDesc="测温点增长率";
        }else if(GzType.GZ_TYPE11.equals(type))
        {
            typeDesc="读表数据告警";
        }else if(GzType.GZ_TYPE12.equals(type))
        {
            typeDesc="容性告警";
        }else if(GzType.GZ_TYPE13.equals(type))
        {
            typeDesc="套管告警";
        }else if(GzType.GZ_TYPE17.equals(type))
        {
            typeDesc="电缆环流阈值告警";
        }else if(GzType.GZ_TYPE18.equals(type))
        {
            typeDesc="电缆环流增长率告警";
        }else if(GzType.GZ_TYPE19.equals(type))
        {
            typeDesc="电缆沟告警";
        }else if(GzType.GZ_TYPE20.equals(type))
        {
            typeDesc="绕组测温告警";
        }else if(GzType.GZ_TYPE21.equals(type))
        {
            typeDesc="测温装置告警";
        }
        return typeDesc;
    }


    /** 相位 */
    public static enum Phase {
        A("1", "A相"), B("2", "B相"), C("3", "C相"), O("O", "全相"),;
        private final String value;
        private final String name;

        private Phase(String value, String name) {
            this.value = value;
            this.name = name;
        }

        public static Phase fromName(String name) {
            Optional<Phase> optional = Arrays.stream(values()).filter(e -> e.getName().equals(name)).findFirst();
            return optional.isPresent() ? optional.get() : null;
        }

        public static Phase fromValue(String value) {
            Optional<Phase> optional =
                Arrays.stream(values()).filter(e -> e.getValue().equals(value)).findFirst();
            return optional.isPresent() ? optional.get() : null;
        }

        public String getValue() {
            return value;
        }

        public String getName() {
            return name;
        }

        public static String getName(String value) {
        	Phase[] paphaseEnums = values();
            for (Phase phaseEnum : paphaseEnums) {
                if (phaseEnum.getValue().equals(value)) {
                    return phaseEnum.getName();
                }
            }
            return "";
        }
    }

    /** 电缆环流相位 */
    public static enum CablePhase {
        A1("1", "A1相"), A2("2", "A2相"), A3("3", "A3相"), B1("4", "B1相"), B2("5", "B2相"), B3("6", "B3相"), C1("7", "C1相"), C2("8", "C2相"), C3("9", "C3相");
        private final String value;
        private final String name;

        private CablePhase(String value, String name) {
            this.value = value;
            this.name = name;
        }

        public String getValue() {
            return value;
        }

        public String getName() {
            return name;
        }

        public static String getName(String value) {
            CablePhase[] CablephaseEnums = values();
            for (CablePhase phaseEnum : CablephaseEnums) {
                if (phaseEnum.getValue().equals(value)) {
                    return phaseEnum.getName();
                }
            }
            return "";
        }
    }

    /** 测温个测温点类型 */
    public static enum TemperPointType {
        A_I("1", "A相进线"),

        B_I("2", "B相进线"),

        C_I("3", "C相进线"),

        A_O("4", "A相出线"),

        B_O("5", "B相出线"),

        C_O("6", "C相出线"),

        IN_SIDE("7", "柜内"),

        OUT_SIDE("8", "柜外测温点");

        private final String value;
        private final String name;

        private TemperPointType(String value, String name) {
            this.value = value;
            this.name = name;
        }

        public static TemperPointType from(String value) {
            Optional<TemperPointType> optional =
                Arrays.stream(values()).filter(e -> e.getValue().equals(value)).findFirst();
            return optional.isPresent() ? optional.get() : null;
        }

        public String getValue() {
            return value;
        }

        public String getName() {
            return name;
        }
    }

    /** 告警来源   1：告警，2：三比值 */
    public static interface MalfunctionSource {
        /** 告警 */
        String WARNING = "1";
        /** 三比值 */
        String TREEVALUE = "2";
    }

    /** 故障单处理状态 */
    public static interface DealStatus {
        /** 未处理 */
        String TO_DEAL = "0";
        /** 已处理 */
        String DEALED = "1";
    }

    /**故障类型*/
    public static interface WarningType{
        /**故障*/
        String FAULT = "1";
        /**误报*/
        String MISREPORT = "2";
    }

    /**视频类型*/
    public static interface SpType{
        /***/
        String GIS_HWCW = "gis_hwcw";
        /***/
        String BLQ_HWCW = "blq_hwcw";
        /***/
        String BYQ_HWCW = "byq_hwcw";
        /***/
        String BYQ_YXGK = "byq_yxgk";
        /***/
        String OTHER = "other";
    }

    /** 考评指标 */
    public static enum Indicators {
        MANUFACTOR("manufactor", "生产厂家"),

        USE_DATE("useDate", "投运时间"),

        REPAIR_COUNT("repairCount", "维修次数"),

        FALSE_ALARM_RATE("falseAlarmRate", "误报率"),

        ACCURACY("accuracy", "精度指标"),

//        ACCURACY("accuracy", "精度偏差"),

        LOSS_RATE("lossRate", "数据缺失率"),

        STABILITY_MAP("stabilityMap", "稳定性"),

        ORIGINAL_STABILITY_MAP("originalStabilityMap", "原边A/B/C相数据稳定性指标"),

        ORIGINAL_NOISE("originalNoise", "原边噪声"),

        SIDE_STABILITY_MAP("sideStabilityMap", "副边A/B/C相数据稳定性指标"),

        SIDE_NOISE("sideNoise", "副边噪声"),

        NEUTRAL_POINT_CURRENT("neutralPointCurrent", "中性点电流"),

        DATA_STATISTICS("dataStatistics", "数据统计考核"),

        DATA_STABILITY_MAP("dataStabilityMap", "数据稳定性指标"),

        EUIP_SENSITIVITY("euipSensitivity", "装置灵敏度"),

    	STATISTICAL_DATA("statisticalData", "落雷次数");
        @Getter
        private final String value;
        @Getter
        private final String name;

        private Indicators(String value, String name) {
            this.value = value;
            this.name = name;
        }

        public static Indicators fromValue(String value) {
            Optional<Indicators> optional = Arrays.stream(values()).filter(e -> e.getValue().equals(value)).findFirst();
            return optional.isPresent() ? optional.get() : null;
        }
    }

    /** 首页分类定义 */
    public static enum HomePagePart {
        YSP, TX, TG, RX, BLQ, JJ;

        public static HomePagePart from(String name) {
            return Arrays.stream(values()).filter(e -> e.name().equals(name)).findFirst().orElse(null);
        }
    }

    /** 报警——故障小类 */
    public static interface DschType {
        /** 故障小类：1——油色谱 */
        String DSCH_TYPE0 = "0";
        String DSCH_TYPE1 = "1";
        String DSCH_TYPE2 = "2";
        String DSCH_TYPE3 = "3";
        String DSCH_TYPE4 = "4";
        String DSCH_TYPE5 = "5";
        String DSCH_TYPE6 = "6";
        String DSCH_TYPE7 = "7";
    }
    /**
     * 根据放电类型返回放电类型中文描述
     * @param type
     * @return
     */
    public static String getDschTypeDescribe(String type) {
    	 String typeDesc="";
         if(DschType.DSCH_TYPE0.equals(type))
         {
             typeDesc="正常";
         }else if(DschType.DSCH_TYPE1.equals(type))
         {
             typeDesc="尖端放电";
         }else if(DschType.DSCH_TYPE2.equals(type))
         {
             typeDesc="悬浮放电";
         }else if(DschType.DSCH_TYPE3.equals(type))
         {
             typeDesc="沿面放电";
         }else if(DschType.DSCH_TYPE4.equals(type))
         {
             typeDesc="内部放电";
         }else if(DschType.DSCH_TYPE5.equals(type))
         {
             typeDesc="颗粒放电";
         }else if(DschType.DSCH_TYPE6.equals(type))
         {
             typeDesc="外部干扰";
         }else if(DschType.DSCH_TYPE7.equals(type))
         {
             typeDesc="其它";
         }
         return typeDesc;
    }

    /**
     * 局放告警状态
     * 0正常：1告警
     *  */
    public static interface WarningStatus {
        /** 正常*/
        String NORMAL = "0";
        /** 告警 */
        String WARN = "1";
    }

    public static String BYQ_ASSESSMENT_RESULT = "[{\"stepId\":1,\"stepName\":\"变压器绝缘试验-油色谱--H2计算\",\"inputParam\":{\"H2(μL/L)\":\"\",\"H2-a值\":\"\",\"H2-b值\":\"\",\"H2权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":2,\"stepName\":\"变压器绝缘试验-油色谱--CO计算\",\"inputParam\":{\"CO(μL/L)\":\"\",\"CO-a值\":\"\",\"CO-b值\":\"\",\"CO权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":3,\"stepName\":\"变压器绝缘试验-油色谱--CO2计算\",\"inputParam\":{\"CO2(μL/L)\":\"\",\"CO2-a值\":\"\",\"CO2-b值\":\"\",\"CO2权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":4,\"stepName\":\"变压器绝缘试验-油色谱--CH4计算\",\"inputParam\":{\"CH4(μL/L)\":\"\",\"CH4-a值\":\"\",\"CH4-b值\":\"\",\"CH4权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":5,\"stepName\":\"变压器绝缘试验-油色谱--C2H2计算\",\"inputParam\":{\"C2H2(μL/L)\":\"\",\"C2H2-a值\":\"\",\"C2H2-b值\":\"\",\"C2H2权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":6,\"stepName\":\"变压器绝缘试验-油色谱--C2H4计算\",\"inputParam\":{\"C2H4(μL/L)\":\"\",\"C2H4-a值\":\"\",\"C2H4-b值\":\"\",\"C2H4权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":7,\"stepName\":\"变压器绝缘试验-油色谱--C2H6计算\",\"inputParam\":{\"C2H6(μL/L)\":\"\",\"C2H6-a值\":\"\",\"C2H6-b值\":\"\",\"C2H6权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":8,\"stepName\":\"变压器绝缘试验-油色谱--总烃计算\",\"inputParam\":{\"总烃(μL/L)\":\"\",\"总烃-a值\":\"\",\"总烃-b值\":\"\",\"总烃权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":9,\"stepName\":\"变压器绝缘试验-油色谱计算\",\"inputParam\":{\"变压器绝缘试验-油色谱试验-分项和\":\"\",\"油色谱权重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":10,\"stepName\":\"变压器绝缘试验--油质试验--油中微水计算\",\"inputParam\":{\"油中微水(mg/L)\":\"\",\"油中微水a值\":\"\",\"油中微水b值\":\"\",\"油中微水权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":11,\"stepName\":\"变压器绝缘试验--油质试验--验油介损计算\",\"inputParam\":{\"油介损\":\"\",\"油介损a值\":\"\",\"油介损b值\":\"\",\"油介损权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":12,\"stepName\":\"变压器绝缘试验--油质试验--油击穿电压（Kv)计算\",\"inputParam\":{\"油击穿电压(Kv)\":\"\",\"油击穿电压a值\":\"\",\"油击穿电压b值\":\"\",\"油击穿电压权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":13,\"stepName\":\"变压器绝缘试验-油质试验计算\",\"inputParam\":{\"油质试验-分项和\":\"\",\"油质试验权重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":14,\"stepName\":\"变压器绝缘试验-糠醛指标计算\",\"inputParam\":{\"糠醛指标\":\"\",\"糠醛指标a值\":\"\",\"糠醛指标b值\":\"\",\"糠醛指标权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":15,\"stepName\":\"变压器绝缘试验-绝缘纸实验计算\",\"inputParam\":{\"纸板聚合度(Dp)\":\"\",\"绝缘纸a值\":\"\",\"绝缘纸b值\":\"\",\"绝缘纸权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":16,\"stepName\":\"变压器绝缘试验--诊断性试验--绝缘纸含水量计算\",\"inputParam\":{\"绝缘纸含水量(%)\":\"\",\"绝缘纸含水量a值\":\"\",\"绝缘纸含水量b值\":\"\",\"绝缘纸含水量权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":17,\"stepName\":\"变压器绝缘试验--诊断性试验--空载电流、空载损耗变化率（%）计算\",\"inputParam\":{\"空载电流、空载损耗变化率(%)\":\"\",\"空载电流、空载损耗变化率a值\":\"\",\"空载电流、空载损耗变化率b值\":\"\",\"空载电流、空载损耗变化率权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":18,\"stepName\":\"变压器绝缘试验--诊断性试验--短路阻抗变化率(%)计算\",\"inputParam\":{\"短路阻抗变化率(%)\":\"\",\"短路阻抗变化率(%)a值\":\"\",\"短路阻抗变化率(%)b值\":\"\",\"短路阻抗变化率(%)权重\":\"\"},\"calculateResult\":\"0.0\"},{\"stepId\":19,\"stepName\":\"变压器绝缘试验--诊断性试验--铁芯接地电流计算\",\"inputParam\":{\"铁芯接地电流(mA)\":\"\",\"铁芯接地电流(mA)a值\":\"\",\"铁芯接地电流(mA)b值\":\"\",\"铁芯接地电流(mA)权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":20,\"stepName\":\"变压器绝缘试验--诊断性试验--绕组直流泄漏电流计算\",\"inputParam\":{\"绕组直流泄漏电流(μA)\":\"\",\"绕组直流泄漏电流a值\":\"\",\"绕组直流泄漏电流b值\":\"\",\"绕组直流泄漏电流权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":21,\"stepName\":\"变压器绝缘试验--诊断性试验计算\",\"inputParam\":{\"绝缘纸含水量计算结果\":\"\",\"空载电流、空载损耗变化率（%）计算结果\":\"\",\"短路阻抗变化率(%)计算结果\":\"\",\"铁芯接地电流(mA)计算结果\":\"\",\"绕组直流泄漏电流计算结果\":\"\"},\"calculateResult\":\"\"},{\"stepId\":22,\"stepName\":\"变压器绝缘试验-诊断性试验计算\",\"inputParam\":{\"诊断性试验权重\":\"\",\"诊断性试验分项合\":\"\"},\"calculateResult\":\"\"},{\"stepId\":23,\"stepName\":\"变压器绝缘试验--例行试验--极化指数计算\",\"inputParam\":{\"极化指数\":\"\",\"极化指数a值\":\"\",\"极化指数b值\":\"\",\"极化指数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":24,\"stepName\":\"变压器绝缘试验--例行试验--局放放电量计算\",\"inputParam\":{\"局放放电量\":\"\",\"局放放电量a值\":\"\",\"局放放电量b值\":\"\",\"局放放电量权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":25,\"stepName\":\"变压器绝缘试验--例行试验--绝缘电阻(MΩ)计算\",\"inputParam\":{\"绝缘电阻(MΩ)\":\"\",\"绝缘电阻(MΩ)a值\":\"\",\"绝缘电阻(MΩ)b值\":\"\",\"绝缘电阻(MΩ)权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":26,\"stepName\":\"变压器绝缘试验--例行试验--绝缘电阻吸收比计算\",\"inputParam\":{\"绝缘电阻吸收比\":\"\",\"绝缘电阻吸收比a值\":\"\",\"绝缘电阻吸收比b值\":\"\",\"绝缘电阻吸收比权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":27,\"stepName\":\"变压器绝缘试验--例行试验--绕组直流电阻相间差(%)计算\",\"inputParam\":{\"绕组直流电阻相间差(%)\":\"\",\"绕组直流电阻相间差(%)a值\":\"\",\"绕组直流电阻相间差(%)b值\":\"\",\"绕组直流电阻相间差(%)权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":28,\"stepName\":\"变压器绝缘试验--例行试验--绕组直流电阻线间差(%)计算\",\"inputParam\":{\"绕组直流电阻线间差(%)\":\"\",\"绕组直流电阻线间差(%)a值\":\"\",\"绕组直流电阻线间差(%)b值\":\"\",\"绕组直流电阻线间差(%)权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":29,\"stepName\":\"变压器绝缘试验--例行试验--绕组绝缘介损计算\",\"inputParam\":{\"绕组绝缘介损\":\"\",\"绕组绝缘介损a值\":\"\",\"绕组绝缘介损b值\":\"\",\"绕组绝缘介损权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":30,\"stepName\":\"变压器绝缘试验--例行试验--铁芯绝缘电阻（MΩ）计算\",\"inputParam\":{\"铁芯接地电阻（MΩ）\":\"\",\"铁芯接地电阻（MΩ）a值\":\"\",\"铁芯接地电阻（MΩ）b值\":\"\",\"铁芯接地电阻（MΩ）权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":31,\"stepName\":\"变压器绝缘试验-例行试验计算\",\"inputParam\":{\"例行试验权重\":\"\",\"例行试验分项合\":\"\"},\"calculateResult\":\"\"},{\"stepId\":32,\"stepName\":\"变压器绝缘试验--声级振动--中性点电流计算\",\"inputParam\":{\"中性点电流a值\":\"\",\"中性点电流b值\":\"\",\"中性点电流权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":33,\"stepName\":\"变压器绝缘试验--声级振动--噪声计算\",\"inputParam\":{\"噪声a值\":\"\",\"噪声b值\":\"\",\"噪声权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":34,\"stepName\":\"变压器绝缘试验--声级振动--原边振动计算\",\"inputParam\":{\"原边振动a值\":\"\",\"原边振动b值\":\"\",\"原边振动权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":35,\"stepName\":\"变压器绝缘试验--声级振动--副边振动计算\",\"inputParam\":{\"副边振动a值\":\"\",\"副边振动b值\":\"\",\"副边振动权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":36,\"stepName\":\"变压器绝缘试验-声级震动计算\",\"inputParam\":{\"声级震动-分项和\":\"\",\"声级震动权重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":37,\"stepName\":\"变压器绝缘试验计算\",\"inputParam\":{\"油色谱\":\"\",\"油质试验\":\"\",\"糠醛指标\":\"\",\"绝缘纸实验\":\"\",\"例行试验\":\"\",\"诊断性试验\":\"\",\"声级振动\":\"\"},\"calculateResult\":\"\"},{\"stepId\":38,\"stepName\":\"变压器附件-变压器器身--油位下降计算\",\"inputParam\":{\"油位下降(%)\":\"\",\"油位下降-a值\":\"\",\"油位下降-b值\":\"\",\"油位下降权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":39,\"stepName\":\"变压器附件-变压器器身--漏油次数计算\",\"inputParam\":{\"漏油次数\":\"\",\"漏油次数-a值\":\"\",\"漏油次数-b值\":\"\",\"漏油次数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":40,\"stepName\":\"变压器附件-变压器器身--变压器噪声计算\",\"inputParam\":{\"变压器噪声(dB)\":\"\",\"变压器噪声-a值\":\"\",\"变压器噪声-b值\":\"\",\"变压器噪声权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":41,\"stepName\":\"变压器附件-变压器器身计算\",\"inputParam\":{\"变压器附件-变压器器身-分项和\":\"\",\"变压器器身权重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":42,\"stepName\":\"变压器附件-变压器冷却系统--水温计算\",\"inputParam\":{\"水温(℃)\":\"\",\"水温-a值\":\"\",\"水温-b值\":\"\",\"水温权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":43,\"stepName\":\"变压器附件-变压器冷却系统--水压计算\",\"inputParam\":{\"水压\":\"\",\"水压-a值\":\"\",\"水压-b值\":\"\",\"水压权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":44,\"stepName\":\"变压器附件-变压器冷却系统--环境温度计算\",\"inputParam\":{\"环境温度(℃)\":\"\",\"环境温度-a值\":\"\",\"环境温度-b值\":\"\",\"环境温度权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":45,\"stepName\":\"变压器附件-变压器冷却系统--风机损坏检修次数计算\",\"inputParam\":{\"风机损坏检修次数\":\"\",\"风机损坏检修次数-a值\":\"\",\"风机损坏检修次数-b值\":\"\",\"风机损坏检修次数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":46,\"stepName\":\"变压器附件-变压器冷却系统计算\",\"inputParam\":{\"变压器附件-变压器冷却系统-分项和\":\"\",\"变压器冷却系统权重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":47,\"stepName\":\"变压器附件-分接开关--油击穿电压变化率计算\",\"inputParam\":{\"油击穿电压变化率(Kv，%)\":\"\",\"油击穿电压变化率-a值\":\"\",\"油击穿电压变化率-b值\":\"\",\"油击穿电压变化率权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":48,\"stepName\":\"变压器附件-分接开关--传动机构有无问题计算\",\"inputParam\":{\"传动机构有无问题\":\"\",\"传动机构有无问题权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":49,\"stepName\":\"变压器附件-分接开关计算\",\"inputParam\":{\"变压器附件-分接开关-分项和\":\"\",\"变压器分接开关权重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":50,\"stepName\":\"变压器附件-非电量保护装置--继电器动作计算\",\"inputParam\":{\"继电器动作\":\"\",\"继电器动作权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":51,\"stepName\":\"变压器附件-非电量保护装置--压力释放阀动作计算\",\"inputParam\":{\"压力释放阀动作\":\"\",\"压力释放阀动作权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":52,\"stepName\":\"变压器附件-非电量保护装置计算\",\"inputParam\":{\"变压器附件-非电量保护装置-分项和\":\"\",\"变压器非电量保护装置重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":53,\"stepName\":\"变压器附件-变压器高压套管--末屏绝缘电阻计算\",\"inputParam\":{\"末屏绝缘电阻（MΩ）\":\"\",\"末屏绝缘电阻-a值\":\"\",\"末屏绝缘电阻-b值\":\"\",\"末屏绝缘电阻权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":54,\"stepName\":\"变压器附件-变压器高压套管--全电流计算\",\"inputParam\":{\"全电流(mA)\":\"\",\"全电流-a值\":\"\",\"全电流-b值\":\"\",\"全电流权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":55,\"stepName\":\"变压器附件-变压器高压套管--容性电流计算\",\"inputParam\":{\"容性电流(mA)\":\"\",\"容性电流-a值\":\"\",\"容性电流-b值\":\"\",\"容性电流权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":56,\"stepName\":\"变压器附件-变压器高压套管--阻性电流计算\",\"inputParam\":{\"阻性电流(mA)\":\"\",\"阻性电流-a值\":\"\",\"阻性电流-b值\":\"\",\"阻性电流权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":57,\"stepName\":\"变压器附件-变压器高压套管--红外温度计算\",\"inputParam\":{\"红外温度(℃)\":\"\",\"红外温度-a值\":\"\",\"红外温度-b值\":\"\",\"红外温度权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":58,\"stepName\":\"变压器附件-变压器高压套管--末屏介损计算\",\"inputParam\":{\"末屏介损(tgδ)\":\"\",\"末屏介损-a值\":\"\",\"末屏介损-b值\":\"\",\"末屏介损权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":59,\"stepName\":\"变压器附件-变压器高压套管--末屏绝缘电容计算\",\"inputParam\":{\"末屏绝缘电容（pF）\":\"\",\"末屏绝缘电容-a值\":\"\",\"末屏绝缘电容-b值\":\"\",\"末屏绝缘电容权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":60,\"stepName\":\"变压器附件-变压器高压套管--套管介损-例行试验计算\",\"inputParam\":{\"套管介损-例行试验(tgδ)\":\"\",\"套管介损-例行试验-a值\":\"\",\"套管介损-例行试验-b值\":\"\",\"套管介损-例行试验权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":61,\"stepName\":\"变压器附件-变压器高压套管--套管H2计算\",\"inputParam\":{\"套管H2(μL/L)\":\"\",\"套管H2-a值\":\"\",\"套管H2-b值\":\"\",\"套管H2权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":62,\"stepName\":\"变压器附件-变压器高压套管--套管CH4计算\",\"inputParam\":{\"套管CH4(μL/L)\":\"\",\"套管CH4-a值\":\"\",\"套管CH4-b值\":\"\",\"套管CH4权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":63,\"stepName\":\"变压器附件-变压器高压套管--套管C2H2计算\",\"inputParam\":{\"套管C2H2(μL/L)\":\"\",\"套管C2H2-a值\":\"\",\"套管C2H2-b值\":\"\",\"套管C2H2权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":64,\"stepName\":\"变压器附件-变压器高压套管计算\",\"inputParam\":{\"变压器附件-变压器高压套管-分项和\":\"\",\"变压器变压器高压套管权重系数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":65,\"stepName\":\"变压器附件\",\"inputParam\":{\"变压器器身\":\"\",\"变压器冷却系统\":\"\",\"分接开关\":\"\",\"非电量保护装置\":\"\",\"变压器高压套管\":\"\"},\"calculateResult\":\"\"},{\"stepId\":66,\"stepName\":\"变压器绝缘试验计算\",\"inputParam\":{\"变压器绝缘试验权重\":\"\",\"变压器绝缘试验分项合\":\"\"},\"calculateResult\":\"\"},{\"stepId\":67,\"stepName\":\"变压器附件计算\",\"inputParam\":{\"变压器附件分项合\":\"\",\"变压器附件权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":68,\"stepName\":\"变压器状态最终健康指数计算\",\"inputParam\":{\"变压器绝缘试验最终结果\":\"\",\"变压器附件最终结果\":\"\"},\"calculateResult\":\"\"}]";

    public static String GIS_ASSESSMENT_RESULT = "[{\"stepId\":1,\"stepName\":\"累计断开次数计算\",\"inputParam\":{\"触头额定断开电流(A)\":\"\",\"累计开断(动作)次数a值\":\"\",\"开断磨损权重\":\"\",\"累计开断(动作)次数b值\":\"\",\"短路断开电流(A)\":\"\",\"累计开断(动作)次数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":2,\"stepName\":\"使用年限计算\",\"inputParam\":{\"使用年限\":\"\",\"使用年限a值\":\"\",\"开断磨损权重\":\"\",\"使用年限b值\":\"\",\"使用年限权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":3,\"stepName\":\"相对磨损程度计算\",\"inputParam\":{\"触头额定断开电流(A)\":\"\",\"相对电磨损程度权重\":\"\",\"开断磨损权重\":\"\",\"相对电磨损程度a值\":\"\",\"相对电磨损程度b值\":\"\",\"短路断开电流(A)\":\"\"},\"calculateResult\":\"\"},{\"stepId\":4,\"stepName\":\"开断磨损计算\",\"inputParam\":{\"使用年限\":\"\",\"相对电磨损\":\"\",\"累计断开动作次数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":5,\"stepName\":\"合闸不同期计算\",\"inputParam\":{\"合闸不同期(ms)\":\"\",\"合闸不同期权重\":\"\",\"合闸不同期b值\":\"\",\"合闸不同期a值\":\"\",\"时间参数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":6,\"stepName\":\"分闸不同期计算\",\"inputParam\":{\"分闸不同期权重\":\"\",\"分闸不同期a值\":\"\",\"分闸不同期b值\":\"\",\"分闸不同期(ms)\":\"\",\"时间参数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":7,\"stepName\":\"时间参数-其他计算\",\"inputParam\":{\"其他权重\":\"\",\"其他\":\"\",\"时间参数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":8,\"stepName\":\"时间参数计算\",\"inputParam\":{\"合闸不同期\":\"\",\"分闸不同期\":\"\",\"其他\":\"\"},\"calculateResult\":\"\"},{\"stepId\":9,\"stepName\":\"刚分速度计算\",\"inputParam\":{\"刚分速度(ms)\":\"\",\"速度特性权重\":\"\",\"刚分速度a值\":\"\",\"刚分速度权重\":\"\",\"刚分速度b值\":\"\"},\"calculateResult\":\"\"},{\"stepId\":10,\"stepName\":\"刚合速度计算\",\"inputParam\":{\"刚合速度b值\":\"\",\"刚合速度权重\":\"\",\"刚合速度(ms)\":\"\",\"速度特性权重\":\"\",\"刚合速度a值\":\"\"},\"calculateResult\":\"\"},{\"stepId\":11,\"stepName\":\"速度特征-其他计算\",\"inputParam\":{\"其他权重\":\"\",\"速度特征权重\":\"\",\"其他\":\"\"},\"calculateResult\":\"\"},{\"stepId\":12,\"stepName\":\"速度特征计算\",\"inputParam\":{\"刚分速度\":\"\",\"刚合速度\":\"\",\"其他\":\"\"},\"calculateResult\":\"\"},{\"stepId\":13,\"stepName\":\"运行数据\",\"inputParam\":{\"时间参数\":\"\",\"速度特征\":\"\",\"运行数据权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":14,\"stepName\":\"导电回路电阻计算\",\"inputParam\":{\"绝缘电阻a值\":\"\",\"绝缘电阻权重\":\"\",\"绝缘电阻(μΩ)\":\"\",\"绝缘电阻b值\":\"\"},\"calculateResult\":\"\"},{\"stepId\":15,\"stepName\":\"介质损耗计算\",\"inputParam\":{\"介质损耗b值\":\"\",\"介质损耗权重\":\"\",\"介质损耗(%)\":\"\",\"介质损耗a值\":\"\"},\"calculateResult\":\"\"},{\"stepId\":16,\"stepName\":\"介质损耗计算\",\"inputParam\":{\"电容量a值\":\"\",\"电容量b值\":\"\",\"电容量(nF)\":\"\",\"电容量权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":17,\"stepName\":\"导电回路电阻计算\",\"inputParam\":{\"导电回路b值\":\"\",\"导电回路a值\":\"\",\"导电回路电阻权重\":\"\",\"导电回路电阻(μΩ)\":\"\"},\"calculateResult\":\"\"},{\"stepId\":18,\"stepName\":\"合闸线圈直流电阻计算\",\"inputParam\":{\"合闸线圈直流电阻a值\":\"\",\"合闸线圈直流电阻(Ω)\":\"\",\"合闸线圈直流电阻b值\":\"\",\"合闸线圈直流电阻权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":19,\"stepName\":\"合闸线圈直流电阻计算\",\"inputParam\":{\"分闸线圈直流电阻权重\":\"\",\"分闸线圈直流电阻b值\":\"\",\"分闸线圈直流电阻a值\":\"\",\"分闸线圈直流电阻(Ω)\":\"\"},\"calculateResult\":\"\"},{\"stepId\":20,\"stepName\":\"运行数据\",\"inputParam\":{\"合闸线圈直流电阻\":\"\",\"绝缘电阻\":\"\",\"电容量\":\"\",\"介质损耗\":\"\",\"运行数据-电气试验权重\":\"\",\"导电回路电阻\":\"\",\"分闸线圈直流电阻\":\"\"},\"calculateResult\":\"\"},{\"stepId\":21,\"stepName\":\"气体泄露（气室压力）计算\",\"inputParam\":{\"气体泄露（气室压力）(Kpa)\":\"\",\"气体泄露（气室压力）权重\":\"\",\"气体泄露（气室压力）b值\":\"\",\"气体泄露（气室压力）a值\":\"\"},\"calculateResult\":\"\"},{\"stepId\":22,\"stepName\":\"气室微水含量计算\",\"inputParam\":{\"微水含量(μl/L)\":\"\",\"微水含量权重\":\"\",\"微水含量a值\":\"\",\"微水含量b值\":\"\"},\"calculateResult\":\"\"},{\"stepId\":23,\"stepName\":\"局放量计算\",\"inputParam\":{\"局放量权重\":\"\",\"局放量\":\"\",\"局放量b值\":\"\",\"局放量a值\":\"\"},\"calculateResult\":\"\"},{\"stepId\":24,\"stepName\":\"局放次数计算\",\"inputParam\":{\"局放次数\":\"\",\"局放次数a值\":\"\",\"局放次数b值\":\"\",\"局放次数权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":25,\"stepName\":\"其他计算\",\"inputParam\":{\"其他权重\":\"\",\"其他\":\"\"},\"calculateResult\":\"\"},{\"stepId\":26,\"stepName\":\"绝缘介质-SF6在线数据\",\"inputParam\":{\"微水含量\":\"\",\"局放次数\":\"\",\"局放量\":\"\",\"气体泄露（气室压力）\":\"\",\"其他\":\"\",\"绝缘介质-SF6在线数据权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":27,\"stepName\":\"使用环境温度计算\",\"inputParam\":{\"使用环境温度a值\":\"\",\"使用环境温度(℃)\":\"\",\"使用环境温度b值\":\"\",\"使用环境温度权重\":\"\",\"工作环境权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":28,\"stepName\":\"使用环境湿度计算\",\"inputParam\":{\"使用环境湿度\":\"\",\"使用环境湿度b值\":\"\",\"使用环境湿度a值\":\"\",\"工作环境权重\":\"\",\"使用环境湿度权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":29,\"stepName\":\"尘埃腐蚀计算\",\"inputParam\":{\"尘埃腐蚀权重\":\"\",\"环境系数\":\"\",\"工作环境权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":30,\"stepName\":\"其他计算\",\"inputParam\":{\"气压、日照、雨量系数\":\"\",\"气压、日照、雨量权重\":\"\",\"工作环境权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":31,\"stepName\":\"工作环境计算\",\"inputParam\":{\"使用环境湿度\":\"\",\"使用环境温度\":\"\",\"气压、日照、雨量\":\"\",\"尘埃、腐蚀\":\"\"},\"calculateResult\":\"\"},{\"stepId\":32,\"stepName\":\"操作机构润滑计算\",\"inputParam\":{\"操作机构润滑权重\":\"\",\"操作机构润滑\":\"\",\"外观情况权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":33,\"stepName\":\"主体、机构外观计算\",\"inputParam\":{\"主体、机构外观\":\"\",\"主体、机构外观权重\":\"\",\"外观情况权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":34,\"stepName\":\"主回路端子计算\",\"inputParam\":{\"主回路端子权重\":\"\",\"主回路端子\":\"\",\"外观情况权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":35,\"stepName\":\"支持绝缘部分计算\",\"inputParam\":{\"支持绝缘部分\":\"\",\"支持绝缘部分权重\":\"\",\"外观情况权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":36,\"stepName\":\"外观情况计算\",\"inputParam\":{\"支持绝缘部分\":\"\",\"主体、机构外观\":\"\",\"主回路端子\":\"\",\"操作机构润滑\":\"\"},\"calculateResult\":\"\"},{\"stepId\":37,\"stepName\":\"厂家设备遗传计算\",\"inputParam\":{\"厂家设备遗传\":\"\",\"生产厂家权重\":\"\",\"厂家设备遗传权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":38,\"stepName\":\"产品成熟度计算\",\"inputParam\":{\"产品成熟度\":\"\",\"产品成熟度权重\":\"\",\"生产厂家权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":39,\"stepName\":\"知名度计算\",\"inputParam\":{\"知名度\":\"\",\"知名度权重\":\"\",\"生产厂家权重\":\"\"},\"calculateResult\":\"\"},{\"stepId\":40,\"stepName\":\"生产厂家计算\",\"inputParam\":{\"厂家设备遗传\":\"\",\"产品成熟度\":\"\",\"知名度\":\"\"},\"calculateResult\":\"\"},{\"stepId\":41,\"stepName\":\"断路器维护得分计算\",\"inputParam\":{\"断路器维护权重\":\"\",\"同类断路器维护\":\"\",\"检修次数\":\"\"},\"calculateResult\":\"\"},{\"stepId\":42,\"stepName\":\"运行参数总得分计算\",\"inputParam\":{\"断路器维护\":\"\",\"生产厂家\":\"\",\"外观情况\":\"\",\"工作环境\":\"\",\"运行参数权重\":\"\"},\"calculateResult\":\"\"}]";
}
