package com.huatek.busi.common;

import lombok.Getter;

/**
 * 变压器评估枚举
 */
public enum TransformerAssessEnum {
    H2("0001", "h2"),
    CH4("0002", "ch4"),
    C2H2("0003", "c2h2"),
    C2H4("0004", "c2h4"),
    C2H6("0005", "c2h6"),
    CO("0007", "co"),
    CO2("0008", "co2"),
    ZJ("0006", "总烃"),
    WATER_IN_OIL("0009", "油中微水"),
    OILL_MEDIUM("0010", "油介质"),
    OIL_BREAKDOWN_VOLTAGE("0011", "油击穿电压"),
    FURFURAL("0012", "糠醛"),
    DEGREE_CARDBOARD("0013", "纸板聚合度"),
    POLARIZATIO_INDEX("0014", "极化指数"),
    PARTIAL_DISCHARGE("0015", "局放"),
    INSULATION_RESISTANCE("0016", "绝缘电阻"),
    INSULATION_RESISTANCE_ABSORPTION_RATIO("0017", "绝缘电阻吸收比"),
    PHASE_DIFFERENCE_DC_RESISTANCE("0018", "绕组直流电阻相间差"),
    LINE_DIFFERENCE_DC_RESISTANCE("0019", "绕组直流电阻线间差"),
    WINDING_INSULATION_DIELECTRIC_LOSS("0020", "绕组绝缘介损"),
    CORE_INSULATION_RESISTANCE("0021", "铁芯绝缘电阻"),


    END_SCREEN_INSULATION_RESISTANCE("0022", "末屏绝缘电阻"),
    CASING_DIELECTRIC_LOSS("0023", "套管介损"),
    CASING_H2("0024", "套管H2"),
    CASING_CH4("0025", "套管CH4"),
    CASING_C2H2("0026", "套管C2H2"),
    WATER_CONTENT_OF_INSULATING_PAPER("0027", "绝缘纸含水量（质量分数%）"),
    NOLOAD_CURRENT_AND_NOLOAD_LOSS_RATE("0028", "空载电流、空载损耗变化率（%）"),
    SHORT_CIRCUIT_IMPEDANCE_CHANGE_RATE("0029", "短路阻抗变化率(%)"),
    VIBRATION_SOUND_LEVEL("0030", "震动、声级(dB)"),

    NEUTRAL_POINT_CURRENT("0103", "中性点电流"),
    NOISE("0104", "噪声"),
    PRIMARY_VIBRATION("0105", "原边振动"),
    SECONDARY_VIBRATION("0106", "副边振动"),
    DC_LEAKAGE_CURRENT_WINDING("0031", "绕组直流泄露电流（μA）"),

    /******************************老附件评估参数，已弃用************************************/
    BYQ_BT("0098", "变压器本体"),
    BYQ_LQXT("0099", "冷却系统"),
    BYQ_FJKG("0100", "分接开关"),
    BYQ_FDLBHZZ("0101", "非电量保护装置"),
    BYQ_TG("0102", "套管"),

    /******************************新增加编码************************************/
    //诊断性试验
    CORE_GROUND_CURRENT("5022", "铁芯接地电流(mA)"),

    //变压器附件--变压器器身
    OIL_LEVEL_DROP("5000", "油位下降(%)"),
    NUMBER_OF_OIL_SPILLS("5001", "漏油次数"),
    TRANSFORMER_NOISE("5002", "变压器噪声(dB)"),

    //变压器附件--变压器冷却系统
    WATER_TEMPERATURE("5003", "水温(℃)"),
    HYDRAULIC_PRESSURE("5004", "水压"),
    ENVIRONMENT_TEMPERATURE("5005", "环境温度(℃)"),
    FAN_DAMAGE_MAINTENANCE_TIMES("5006", "风机损坏检修次数"),

    //变压器附件--分接开关
    RATE_OF_CHANGE_OF_OIL_BREAKDOWN_VOLTAGE("5007", "油击穿电压变化率（Kv，%）"),
    TRANSMISSION_MECHANISM_PROBLEM("5008", "传动机构有无问题(Y/N)"),

    //变压器附件--非电量保护装置
    ACTUATING_OF_RELAY("5009", "继电器动作"),
    PRESSURE_RELEASE_VALVE_ACTION("5010", "压力释放阀动作"),

    //变压器附件--变压器高压套管
    FINAL_SCREEN_INSULATION_RESISTANCE("5011", "末屏绝缘电阻（MΩ）"),
    TOTAL_CURRENT("5012", "全电流(mA)"),
    CAPACITATIVE_CURRENT("5013", "容性电流(mA)"),
    RESISTIVE_CURRENT("5014", "阻性电流(mA)"),
    INFRARED_TEMPERATURE("5015", "红外温度(℃)"),
    ROUTINE_TEST_OF_CASING_DIELECTRIC_DAMAGE("5016", "套管介损-例行试验(tgδ"),
    FINAL_SCREEN_DIELECTRIC_LOSS("5017", "末屏介损(tgδ)"),
    LAST_SCREEN_INSULATION_CAPACITANCE("5018", "末屏绝缘电容（pF）"),
    HIGH_PRESSURE_CASING_H2("5019", "末屏绝缘电容（pF）"),
    HIGH_PRESSURE_CASING_CH4("5020", "末屏绝缘电容（pF）"),
    HIGH_PRESSURE_CASING_C2H2("5021", "末屏绝缘电容（pF）"),

//    ENVIRONMENTAL_GRADE("5023","变压器设计、标牌、运行环境、负荷权重"),


    /*****************************************变压器负荷率*****************************************/
    WORKING_VOLTAGE("5024", "发电电压"),
    WORKING_CURRENT("5025", "发电电流"),
    WORKING_TIME("5026", "发电时长"),
    PUMPING_VOLTAGE("5027", "抽水电压"),
    PUMPING_CURRENT("5028", "抽水电流"),
    PUMPING_TIME("5029", "抽水时长"),
    HIGH_PRESSURE_CASING_CAPACITANCE("5030", "（高压套管）电容量"),

    /*****************************************变压器油色谱-补充参数（偏差率计算）*****************************************/
    N2("5032", "N2"),
    O2("5031", "O2");


    @Getter
    private final String key;
    @Getter
    private final String value;

    TransformerAssessEnum(String key, String value) {
        this.key = key;
        this.value = value;
    }
}
