package com.huatek.busi.entity;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

import org.springframework.format.annotation.DateTimeFormat;

import com.huatek.torch.sql.annotation.FieldName;
import com.huatek.torch.sql.annotation.TableName;
import com.huatek.torch.sql.beans.Pojo;

import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * 变压器/电抗器——气象：021011、023003、024008、025001 entity
 *
 * @author anker_cheng
 * @date Aug 2, 2019 2:12:59 PM
 */
@Data
@EqualsAndHashCode(callSuper = false)
@TableName("transformer_meteorological")
public class TransformerMeteorological extends Pojo implements Serializable  {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @FieldName("id")
    private String id;

    /**
     * CAC 的唯一标识（17 位码）
     */
    @FieldName("cac_id")
    private String cacId;

    /**
     * 监测数据组的数目
     */
    @FieldName("data_node_num")
    private BigDecimal dataNodeNum;

    /**
     * 在线监测装置的唯一标识（17 位码）
     */
    @FieldName("sensor_id")
    private String sensorId;

    /**
     * 监测类型编码
     */
    @FieldName("cac_monitor_type_code")
    private String cacMonitorTypeCode;

    /**
     * 在线监测装置对应的被监测设备的 唯一标识（17 位码）
     */
    @FieldName("equipment_id")
    private String equipmentId;

    /**
     * 数据采集时间，格式为：yyyy-MM-dd HH:mm:ss
     */
    @FieldName("time_stamp")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime timeStamp;

    /**
     * 主设备编号
     */
    @FieldName("equipment_code")
    private String equipmentCode;

    /**
     * 外挂设备编号
     */
    @FieldName("ext_equipment_code")
    private String extEquipmentCode;

    /**
     * 站点ID
     */
    @FieldName("site_id")
    private String siteId;

    /**
     * 被监测设备相别
     */
    @FieldName("phase")
    private String phase;

    /**
     * 气温(℃)
     */
    @FieldName("air_temperature")
    private String airTemperature;

    /**
     * 气压
     */
    @FieldName("air_pressure")
    private String airPressure;

    /**
     * 湿度
     */
    @FieldName("humidity")
    private String humidity;

    /**
     * 降雨量 
     */
    @FieldName("precipitation")
    private String precipitation;

    /**
     * 降水强度
     */
    @FieldName("precipitation_intensity")
    private String precipitationIntensity;

    /**
     * 光辐射强度
     */
    @FieldName("radiation_intensity")
    private String radiationIntensity;

    /**
     * 20230101fdh新增风速
     * 风速
     */
    @FieldName("wdgustspd")
    private String wdgustspd;

    /**
     * 主设备ID
     */
    @FieldName("main_equipment_id")
    private String mainEquipmentId;

    /**
     * 外挂设备ID
     */
    @FieldName("sub_equipment_id")
    private String subEquipmentId;

    /**
     * 站点设备树ID
     */
    @FieldName("main_tree_id")
    private String mainTreeId;

    /**
     * 外挂设备树ID
     */
    @FieldName("sub_tree_id")
    private String subTreeId;
    
    /**
     * hbase中的rowkey
     */
    @FieldName("hbase_rowkey")
    private String hbaseRowkey;
}