package com.huatek.busi.vo;

import com.huatek.torch.sql.annotation.FieldName;
import com.huatek.torch.sql.annotation.TableName;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 发电机振动/压力阈值表
 *
 * @author Leo 
 * @since  2023-04-13
 */

@Data
public class GeneratorAmplThresholdVo implements Serializable {

	private static final long serialVersionUID = 42L;
	/**
	* 主键ID
	*/
	@ApiModelProperty("主键ID")
	private String id;

	/**
	* 站点ID
	*/
	@ApiModelProperty("站点ID")
	private String siteId;

	/**
	* 站点设备树ID
	*/
	@ApiModelProperty("站点设备树ID")
	private String mainTreeId;

	/**
	* 传感器编码
	*/
	@ApiModelProperty("传感器编码")
	private String sensorCode;

	/**
	* 设备运行状态：0-无  1-发电  2-抽水  3-空闲
	*/
	@ApiModelProperty("设备运行状态：0-无  1-发电  2-抽水  3-空闲")
	private String workStatus;

	/**
	 *  设备类型(6：发电机)
	 */
	@ApiModelProperty("设备类型(6：发电机)")
	private String type;

	/**
	* 振动X轴位移μm阈值
	*/
	@ApiModelProperty("振动X轴位移(μm)阈值")
	private String amplXThreshold;

	/**
	* 振动Y轴位移μm阈值
	*/
	@ApiModelProperty("振动Y轴位移(μm)阈值")
	private String amplYThreshold;

	/**
	* 振动Z轴位移μm阈值
	*/
	@ApiModelProperty("振动Z轴位移(μm)阈值")
	private String amplZThreshold;

	/**
	* 振动X轴频率Hz阈值
	*/
	@ApiModelProperty("振动X轴频率Hz阈值")
	private String freqXThreshold;

	/**
	* 振动Y轴频率Hz阈值
	*/
	@ApiModelProperty("振动Y轴频率Hz阈值")
	private String freqYThreshold;

	/**
	* 振动Z轴频率Hz阈值
	*/
	@ApiModelProperty("振动Z轴频率Hz阈值")
	private String freqZThreshold;

	/**
	* 振动X轴速度s阈值
	*/
	@ApiModelProperty("振动X轴速度s阈值")
	private String spdXThreshold;

	/**
	* 振动Y轴速度s阈值
	*/
	@ApiModelProperty("振动Y轴速度s阈值")
	private String spdYThreshold;

	/**
	* 振动Z轴速度s阈值
	*/
	@ApiModelProperty("振动Z轴速度s阈值")
	private String spdZThreshold;

	/**
	 * 空气间隙0度位移μm阈值
	 */
	@ApiModelProperty("空气间隙0度位移(μm)阈值")
	private String aircapAmThreshold;

	/**
	 * 空气间隙90度位移μm阈值
	 */
	@ApiModelProperty("空气间隙90度位移(μm)阈值")
	private String aircapBmThreshold;

	/**
	 * 空气间隙180度位移μm阈值
	 */
	@ApiModelProperty("空气间隙180度位移(μm)阈值")
	private String aircapCmThreshold;

	/**
	 * 空气间隙270度位移μm阈值
	 */
	@ApiModelProperty("空气间隙270度位移(μm)阈值")
	private String aircapDmThreshold;

	/**
	 * 压力1 Mpa阈值
	 */
	@ApiModelProperty("压力1(Mpa)阈值")
	private String pvAThreshold;

	/**
	 * 压力2 Mpa阈值
	 */
	@ApiModelProperty("压力2(Mpa)阈值")
	private String pvBThreshold;

	/**
	* 创建时间
	*/
	private LocalDateTime createdTime;

	/**
	* 创建人
	*/
	private String creator;

	/**
	* 修改时间
	*/
	private LocalDateTime modifiedTime;

	/**
	* 修改人
	*/
	private String modifier;

}