package com.huatek.busi.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

import org.springframework.format.annotation.DateTimeFormat;

import com.huatek.busi.common.annotation.ExcelAnnotation;

import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * 变压器/电抗器——油中溶解气体：021002 Vo
 *
 * @author anker_cheng
 * @date Aug 2, 2019 2:13:18 PM
 */
@Data
@EqualsAndHashCode(callSuper = false)
public class TransformerEpaDataVo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private String id;

    /**
     * CAC 的唯一标识（17 位码）
     */
    private String cacId;

    /**
     * 监测数据组的数目
     */
    private BigDecimal dataNodeNum;


    /**
     * 监测类型编码
     */
    private String cacMonitorTypeCode;

    /**
     * 在线监测装置对应的被监测设备的 唯一标识（17 位码）
     */
    private String equipmentId;


    /**
     * 主设备编号
     */
    private String equipmentCode;
    
    /**
     * 设备编码
     */
    @ExcelAnnotation(exportName = "设备编号")
    private String systemCode;
    
    /**
     * 设备名称
     */
    @ExcelAnnotation(exportName = "设备名称")
    private String equipmentName;
    

    /**
     * 在线监测装置的唯一标识（17 位码）
     */
    @ExcelAnnotation(exportName = "传感器编号")
    private String sensorId;
    
    /**
     * 传感器名称
     */
    @ExcelAnnotation(exportName = "传感器名称")
    private String sensorName;
    

    /**
     * 数据采集时间，格式为：yyyy-MM-dd HH:mm:ss
     */
    @ExcelAnnotation(exportName = "监测时间")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime timeStamp;

    /**
     * 外挂设备编号
     */
    private String extEquipmentCode;

    /**
     * 站点ID
     */
    private String siteId;

    /**
     * 被监测设备相别
     */
    private String phase;

    /**
     * 氢气（μL/L）
     */
    @ExcelAnnotation(exportName = "氢气含量（μL/L）")
    private String h2;

    /**
     * 甲烷（μL/L）
     */
    @ExcelAnnotation(exportName = "甲烷含量（μL/L）")
    private String ch4;

    /**
     * 乙烷（μL/L）
     */
    @ExcelAnnotation(exportName = "乙烷含量（μL/L）")
    private String c2h6;

    /**
     * 乙烯（μL/L）
     */
    @ExcelAnnotation(exportName = "乙烯含量（μL/L）")
    private String c2h4;

    /**
     * 乙炔（μL/L）
     */
    @ExcelAnnotation(exportName = "乙炔含量（μL/L）")
    private String c2h2;

    /**
     * 一氧化碳（μL/L）
     */
    @ExcelAnnotation(exportName = "一氧化碳含量（μL/L）")
    private String co;

    /**
     * 二氧化碳（μL/L）
     */
    @ExcelAnnotation(exportName = "二氧化碳含量（μL/L）")
    private String co2;

    /**
     * 氧气（μL/L）
     */
    @ExcelAnnotation(exportName = "氧气含量（μL/L）")
    private String o2;
    
    /**
     * 水分
     */
    @ExcelAnnotation(exportName = "水分含量（μL/L）")
    private String h2o;

    /**
     * 氮气（μL/L）
     */
    @ExcelAnnotation(exportName = "氮气含量（μL/L）")
    private String n2;

    /**
     * 总可燃气体含量（μL/L）
     */
    @ExcelAnnotation(exportName = "总可燃气体含量（μL/L）")
    private String cmbuGas;

    /**
     * 总烃（μL/L）
     */
    @ExcelAnnotation(exportName = "总烃含量（μL/L）")
    private String totalHydrocarbon;
    
    /**
     * 总可燃气体
     */
    @ExcelAnnotation(exportName = "总可燃气体（μL/L）")
    private String totalGas;

    /**
     * 载气压力(KPa)
     */
    @ExcelAnnotation(exportName = "载气压力(KPa)")
    private String gasPress;



    /**
     * 主设备ID
     */
    private String mainEquipmentId;

    /**
     * 外挂设备ID
     */
    private String subEquipmentId;

    /**
     * 站点设备树ID
     */
    private String mainTreeId;

    /**
     * 外挂设备树ID
     */
    private String subTreeId;
}