package com.huatek.busi.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDateTime;

import org.springframework.format.annotation.DateTimeFormat;

import com.huatek.busi.common.annotation.ExcelAnnotation;

import lombok.Data;
import lombok.EqualsAndHashCode;

/**
 * 变压器/电抗器——红外测温：021010、022002、023002、024007 Vo
 *
 * @author anker_cheng
 * @date Aug 2, 2019 2:13:18 PM
 */
@Data
@EqualsAndHashCode(callSuper = false)
public class TransformerInfraredTemperatureVo implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private String id;


    /**
     * 监测数据组的数目
     */
    private BigDecimal dataNodeNum;

    /**
     * 监测类型编码
     */
    private String cacMonitorTypeCode;

    /**
     * 在线监测装置对应的被监测设备的 唯一标识（17 位码）
     */
    private String equipmentId;


    /**
     * 主设备编号
     */
    private String equipmentCode;

    /**
     * 设备编码
     */
    @ExcelAnnotation(exportName = "设备编号")
    private String systemCode;
    
    /**
     * 外挂设备编号
     */
    private String extEquipmentCode;
    
    /**
     * 设备名称
     */
    @ExcelAnnotation(exportName = "设备名称")
    private String equipmentName;
    
    /**
     * 在线监测装置的唯一标识（17 位码）
     */
    @ExcelAnnotation(exportName = "传感器编号")
    private String sensorId;
    
    
    /**
     * 在线监测装置的唯一标识（17 位码）
     */
    @ExcelAnnotation(exportName = "传感器名称")
    private String sensorName;
    
    /**
     * 数据采集时间，格式为：yyyy-MM-dd HH:mm:ss
     */
    @ExcelAnnotation(exportName = "监测时间")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime timeStamp;
    
    /**
     * 被监测设备相别
     */
    @ExcelAnnotation(exportName = "被监测设备相别")
    private String phase;

    /**
     * 最高温度
     */
    @ExcelAnnotation(exportName = "最高温度（℃）")
    private String maxTmp;

    /**
     * 最低温度
     */
    @ExcelAnnotation(exportName = "最低温度（℃）")
    private String minTmp;

    /**
     * 平均温度
     */
    @ExcelAnnotation(exportName = "平均温度（℃）")
    private String avgTmp;
    
    /**
     * CAC 的唯一标识（17 位码）
     */
    @ExcelAnnotation(exportName = "CAC唯一标识")
    private String cacId;
    
    /**
     * 气温
     */
    private String airTemperature;
    
    /**
     * 气压
     */
    private String airPressure;
    
    /**
     * 湿度
     */
    private String humidity;

    /**
     * 站点ID
     */
    private String siteId;

    /**
     * 主设备ID
     */
    private String mainEquipmentId;

    /**
     * 外挂设备ID
     */
    private String subEquipmentId;

    /**
     * 站点设备树ID
     */
    private String mainTreeId;

    /**
     * 外挂设备树ID
     */
    private String subTreeId;
    /**
     * 设备状态    
     */
    private String runState;
}