package com.huatek.busi.mapper;

import java.util.List;

import com.huatek.busi.vo.BusiParamTransformerVo;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import com.huatek.busi.vo.BusiParamGisVo;

/**
 * gis的权重系数维护表 Mapper
 *
 * @author anker_cheng
 * @date Jul 12, 2019 2:57:22 PM
 */
@Repository
public interface BusiParamGisMapper {
    /**
     * 获取一级设备分析参数列表
     *
     * @param siteId
     *            站点ID
     * @param mainEquipmentId
     *            主设备ID
     * @return 分析参数列表
     */
    List<BusiParamTransformerVo> findFirstLevelParams(@Param("siteId") String siteId,
        @Param("mainEquipmentId") String mainEquipmentId,@Param("number") Integer number);


    /**
     * 获取一级设备分析参数列表(无值)
     *
     * @param siteId
     *            站点ID
     * @param mainEquipmentId
     *            主设备ID
     * @return 分析参数列表
     */
    List<BusiParamTransformerVo> findNotValueFirstLevelParams(@Param("siteId") String siteId,
                                                              @Param("mainEquipmentId") String mainEquipmentId,@Param("number") Integer number);


    /**
     * 获取分析参数权重
     *
     * @param siteId
     *            站点ID
     * @param mainEquipmentId
     *            主设备ID
     * @return 分析参数列表
     */
    List<BusiParamTransformerVo> findBusiParamGisWeights(@Param("siteId") String siteId,
        @Param("mainEquipmentId") String mainEquipmentId);


    /**
     * 获取分析参数的子分类列表
     *
     * @param siteId
     *            站点ID
     * @param mainEquipmentId
     *            主设备ID
     * @param pname
     *            上级参数名称
     * @return 分析参数列表
     */
    List<BusiParamTransformerVo> findSubParams(@Param("siteId") String siteId,
        @Param("mainEquipmentId") String mainEquipmentId, @Param("pname") String pname,@Param("number") Integer number);

    List<BusiParamTransformerVo> findBusiParamGisManual(@Param("siteId") String siteId, @Param("mainEquipmentId") String mainEquipmentId);

    BusiParamTransformerVo findFirstLevelNumber(@Param("siteId") String siteId, @Param("mainEquipmentId") String mainEquipmentId);
}
