package com.huatek.busi.mapper;

import java.util.List;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import com.huatek.busi.dto.EquipmentInfoDto;
import com.huatek.busi.vo.BusiTreeNodeVo;

/**
  * @ClassName: BusiSubTreeMapper
  * @FullClassPath: com.huatek.busi.mapper.BusiSubTreeMapper
  * @Description: TODO
  * @author: Arno
  * @date: Jun 28, 2019 2:47:45 PM
  * @version: 1.0
  */

@Repository
public interface BusiSubTreeMapper { 
	
	/** 
	* @Title: getTransformerBySensor 
	* @Description: 根据传感器编码获取变压器对象 
	* @createDate: Jun 28, 2019 4:54:12 PM
	* @param    sensorCode  传感器系统编码
	* @return   EquipmentInfoDto    
	* @throws 
	*/
	EquipmentInfoDto getTransformerBySensor(@Param("sensorCode")String sensorCode);

	
	/** 
	* @Title: getGisBySensor 
	* @Description: 根据传感器编码获取GIS对象 
	* @createDate: Jun 28, 2019 4:54:12 PM
	* @param    sensorCode  传感器系统编码
	* @return   EquipmentInfoDto    
	* @throws 
	*/ 
	EquipmentInfoDto getGisBySensor(@Param("sensorCode")String sensorCode);

	/**
	 * @Title: getGisBySensor
	 * @Description: 根据传感器编码获取Generator对象
	 * @createDate: Jun 28, 2019 4:54:12 PM
	 * @param    sensorCode  传感器系统编码
	 * @return   EquipmentInfoDto
	 * @throws
	 */
	EquipmentInfoDto getGeneratorBySensor(@Param("sensorCode")String sensorCode);

	/**
	 * @Title: getGisBySensor
	 * @Description: 根据传感器编码获取Cable对象
	 * @createDate: Jun 28, 2019 4:54:12 PM
	 * @param    sensorCode  传感器系统编码
	 * @return   EquipmentInfoDto
	 * @throws
	 */
	EquipmentInfoDto getCableBySensor(@Param("sensorCode")String sensorCode);

	/** 
	* @Title: getArresterBySensor 
	* @Description: 根据传感器编码获取避雷器对象 
	* @createDate: Jun 28, 2019 4:54:12 PM
	* @param    sensorCode  传感器系统编码
	* @return   EquipmentInfoDto    
	* @throws 
	*/ 
	EquipmentInfoDto getArresterBySensor(@Param("sensorCode")String sensorCode);
	
	/** 
    * @Title: getArresterBySensor 
    * @Description: 根据传感器编码获取其他设备对象 
    * @createDate: Jun 28, 2019 4:54:12 PM
    * @param    sensorCode  传感器系统编码
    * @return   EquipmentInfoDto    
    * @throws 
    */ 
    EquipmentInfoDto getOtherBySensor(@Param("sensorCode")String sensorCode);
	    
	    
	
	/** 
	* @Title: getTransformerBySensor 
	* @Description: 根据传感器编码获取测温对象 
	* @createDate: Jun 28, 2019 4:54:12 PM
	* @param    sensorCode  传感器系统编码
	* @return   EquipmentInfoDto    
	* @throws 
	*/ 
	EquipmentInfoDto getCwBySensor(@Param("sensorCode")String sensorCode);

	/** 
	* @Title: getTransformerSubTree 
	* @Description: 获取变压器外挂设备树 
	* @createDate: Jul 16, 2019 3:06:55 PM
	* @param    equipmentId  变压器树ID
	* @return   List<BusiTreeNodeVo>    
	* @throws 
	*/ 
	List<BusiTreeNodeVo>  getTransformerSubTree(@Param("equipmentId")String equipmentId, @Param("equipmentType")String equipmentType);
	
	/** 
	* @Title: getTransformerSubTree 
	* @Description: 获取GIS外挂设备树 
	* @createDate: Jul 16, 2019 3:06:55 PM
	* @param    equipmentId  变压器树ID
	* @return   List<BusiTreeNodeVo>    
	* @throws 
	*/ 
	List<BusiTreeNodeVo>  getGisSubTree(@Param("equipmentId")String equipmentId, @Param("equipmentType")String equipmentType);

	/**
	 * @Title: getTransformerSubTree
	 * @Description: 获取GIS外挂设备树
	 * @createDate: Jul 16, 2019 3:06:55 PM
	 * @param    equipmentId  变压器树ID
	 * @return   List<BusiTreeNodeVo>
	 * @throws
	 */
	List<BusiTreeNodeVo>  getGenSubTree(@Param("equipmentId")String equipmentId, @Param("equipmentType")String equipmentType);

	/**
	* @Title: getTransformerSubTree
	* @Description: 获取避雷器外挂设备树
	* @createDate: Jul 16, 2019 3:06:55 PM
	* @param    equipmentId  变压器树ID
	* @return   List<BusiTreeNodeVo>
	* @throws
	*/
	List<BusiTreeNodeVo>  getArresterSubTree(@Param("equipmentId")String equipmentId, @Param("equipmentType")String equipmentType);
	
   /** 
    * @Title: getTransformerSubTree 
    * @Description: 获取避雷器外挂设备树 
    * @createDate: Jul 16, 2019 3:06:55 PM
    * @param    equipmentId  变压器树ID
    * @return   List<BusiTreeNodeVo>    
    * @throws 
    */
    List<BusiTreeNodeVo>  getOtherSubTree(@Param("equipmentId")String equipmentId, @Param("equipmentType")String equipmentType);


	/**
	 * @Title: getCableSubTree
	 * @Description: 获取发电机外挂设备树
	 * @createDate: Jul 16, 2019 3:06:55 PM
	 * @param    equipmentId  变压器树ID
	 * @return   List<BusiTreeNodeVo>
	 * @throws
	 */
	List<BusiTreeNodeVo>  getGeneratorSubTree(@Param("equipmentId")String equipmentId, @Param("equipmentType")String equipmentType);


    /**
	 * @Title: getCableSubTree
	 * @Description: 获取电缆外挂设备树
	 * @createDate: Jul 16, 2019 3:06:55 PM
	 * @param    equipmentId  变压器树ID
	 * @return   List<BusiTreeNodeVo>
	 * @throws
	 */
	List<BusiTreeNodeVo>  getCableSubTree(@Param("equipmentId")String equipmentId, @Param("equipmentType")String equipmentType);
}